@@ -29,9 +29,9 @@ import nnabla as nn
 from nnabla.ext_utils import get_extension_context
 from pydub import AudioSegment
 from pydub.utils import mediainfo
-from args import get_inference_args
-import model
-from utils import bandwidth_to_max_bin
+from .args import get_inference_args
+from .model import *
+from .utils import bandwidth_to_max_bin
 
 
 def istft(X, rate=44100, n_fft=4096, n_hopsize=1024):
@@ -73,7 +73,7 @@ def separate(audio, args):
         nn.load_parameters(args.model)
         for j, target in enumerate(args.targets):
             if j == 0:
-                unmix_target = model.OpenUnmix_CrossNet(
+                unmix_target = OpenUnmix_CrossNet(
                     max_bin=max_bin, is_predict=True)
                 mix_spec, msk, _ = unmix_target(audio_nn, test=True)
                 # Network output is (nb_frames, nb_samples, nb_channels, nb_bins)
@@ -84,7 +84,7 @@ def separate(audio, args):
         # Run UMX Inference
         for j, target in enumerate(args.targets):
             with nn.parameter_scope(target):
-                unmix_target = model.OpenUnmix(max_bin=max_bin)
+                unmix_target = OpenUnmix(max_bin=max_bin)
                 nn.load_parameters(f"{os.path.join(args.model, target)}.h5")
                 # Network output is (nb_frames, nb_samples, nb_channels, nb_bins)
                 V.append(unmix_target(audio_nn, test=True).d[:, 0, ...])
@@ -95,7 +95,7 @@ def separate(audio, args):
         # only exponentiate the model if we use softmask
         V = V ** args.alpha
 
-    real, imag = model.get_stft(audio_nn, center=True)
+    real, imag = get_stft(audio_nn, center=True)
 
     # convert to complex numpy type
     X = real.d + imag.d * 1j
@@ -187,7 +187,7 @@ def test():
         if not args.out_dir:
             model_path = Path(args.model)
             if not model_path.exists():
-                output_path = Path(Path(input_file).stem + '_' + model)
+                output_path = Path(Path(input_file).stem + '_' + model_path.stem)
             else:
                 output_path = Path(
                     Path(input_file).stem + '_' + model_path.stem
